# RTLS Platform Services

## Common

<!-- START doctoc generated TOC please keep comment here to allow auto update -->
<!-- DON'T EDIT THIS SECTION, INSTEAD RE-RUN doctoc TO UPDATE -->

- [Features](#features)
    - [REST API Documentation](#rest-api-documentation)
- [Tech Stack](#tech-stack)
    - [rtls-platform-rest-server](#rtls-platform-rest-server)
    - [rtls-platform-message-processor](#rtls-platform-message-processor)
    - [rtls-platform-sync](#rtls-platform-sync)
- [Architecture Overview](#architecture-overview)
- [Development env configuration](#development-env-configuration)
    - [Prerequisites](#prerequisites)
    - [Clone the project](#clone-the-project)
    - [Configure](#configure)
- [Usage](#usage)
    - [Running the Service Locally](#running-the-service-locally)
- [Running Tests](#running-tests)
    - [Create tests](#create-tests)
- [Package Release](#package-release)
- [Conventions](#conventions)
    - [Code style](#code-style)
        - [Formatting rules](#formatting-rules)
        - [Naming rules](#naming-rules)

<!-- END doctoc generated TOC please keep comment here to allow auto update -->

## Features

This GitHub repository is a mono repository for building a backend services
like `Platform REST API Server`, `Platform Message Processor` and `Solution Platform Sync`.
The repository is organized into three main components:

- `rtls-platform-rest-server`: The web server component that is implementing platform REST API for managing main
  entities like `nodes`, `tags`, `trackables` etc.
- `rtls-platform-message-processor`: The message processor component is a heart of the server and responsible for
  processing incoming messages from `rtls-platform-bin-json-converter`, and `rtls-gateway`. The main responsibilities
  of message processor is extending raw system messages with platform level information and messages proxying.
- `rtls-platform-sync`: Is the module that is synchronized data between solutions and platform rest servers and
  databases, starts on `rtls-server` restart

### REST API Documentation

Swagger documentation is accessible by route `{host}/api/platform/docs/`

## Tech Stack

### rtls-platform-rest-server

- **Language**: JavaScript
- **Platform**: Node.js
- **Framework**: Express
- **Database**: Redis

### rtls-platform-message-processor

- **Language**: JavaScript
- **Platform**: Node.js
- **Framework**: Express
- **Database**: Redis
- **Other technologies**: ZMQ

### rtls-platform-sync

- **Language**: JavaScript
- **Platform**: Node.js
- **Database**: Redis, MariaDb

## Architecture Overview

...

## Development env configuration

### Prerequisites

- Ubuntu 22.04
- [install node v20 with yarn](https://github.com/rpplabs/rtls-frontend/blob/dev/README.md#install-nodejs)
- [Configure RTLS repository](https://github.com/rpplabs/rtls-frontend/blob/dev/README.md#configure-rtls-repository)
- [Install MariaDB 10.6.18](https://github.com/rpplabs/rtls-frontend/blob/dev/README.md#install-mariadb-10618)
- Install `Redis`

```shell
sudo apt update
sudo apt install redis-server

```

### Clone the project

- Add public ssh key to [your account](https://github.com/settings/keys)

- Clone the repository

```shell
# via https
git clone https://github.com/rpplabs/rtls-platform-rest-server.git

# OR via ssh key
git clone git@github.com:rpplabs/rtls-platform-rest-server.git

cd rtls-platform-rest-server

```

### Configure

- For packages configuration create `.env` files:

```shell
cp apps/message-processor/.env.defaults apps/message-processor/.env
cp apps/rest-server/.env.defaults apps/rest-server/.env
cp apps/sync/.env.defaults apps/sync/.env

```

- Install latest version of [Pub-sub package](https://redpointpositioning.atlassian.net/wiki/spaces/REDPOINT/pages/1942683786/RTLS-Server+releases)

```shell
sudo apt install rtls-pub-sub-proxyd=8.2.1-9

```

- Update environment variables (e.g. database password)

- install server node packages

```shell
yarn

```

## Usage

### Running the Service Locally

[Platform message processor](apps/message-processor/README.md#running-the-service-locally)
[Platform rest server](apps/rest-server/README.md#running-the-service-locally)
[Sync](apps/sync/README.md#running-the-service-locally)

## Running Tests

- TODO: issue with zmq tests

[Platform message processor](apps/message-processor/README.md#running-tests)
[Platform rest server](apps/rest-server/README.md#running-tests)
[Sync](apps/sync/README.md#running-tests)

#### Create tests

- unit tests should be places at the same level as the tested file
- unit test name should include the name of the file that is contains covered functionality and obey a
  pattern `{filename}.test.mjs`

- e2e tests should be places at the `e2e/integration` folder of each application
- e2e test name should include the name of the entity that is testing and obey a pattern `{filename}.test.mjs`

## Package Release

[Platform message processor](apps/message-processor/README.md#package-release)
[Platform rest server](apps/rest-server/README.md#package-release)
[Sync](apps/sync/README.md#package-release)

## Conventions

### Code style

#### Formatting rules

- please, follow the eslint rules described in project (with this purpose setting up your IDE with
  the [.eslintrc](.eslintrc));

#### Naming rules

- please name the variables and constants in a human-readable manner (ex. use `getUsersSql` instead of `sql1`);
- please use the `camelCase` style in name the variables and constants (ex. `getUsersSql` instead of `get_users_sql`);
- please use upper case naming for constants that are not changeable in project (ex. `MAX_ROWS_NUMBER`);
- please use `JavaScript` conventions in naming the classes, constructors(functions) and others entities (classes should
  be named wih the first capital latter);
