import assert from 'assert';
import { createRequire } from 'module';

import { ZMQ_PUB_CHANNELS, ZMQ_SUB_CHANNELS } from '../../lib/system/constants.mjs';
import { ZmqObserver, ZmqPublisher } from '../utils/index.mjs';
import { Server, createData, initRepoData, clearRepoData } from './helpers.mjs';
const require = createRequire(import.meta.url);
const DbSeeds = require('../seeds/data.json');

describe('Handle ~data message and re translate to $data', function () {
    // ~data and $data descriptions: https://redpointpositioning.atlassian.net/wiki/spaces/REDPOINT/pages/1314031083/Platform+Message+Processor#Handling-%E2%80%9Cdata%E2%80%9D-messages
    const zmqObserver = new ZmqObserver();
    const zmqPublisher = new ZmqPublisher();

    before(async function () {
        await Server().init();
        await initRepoData();
        zmqObserver.init();
        await zmqPublisher.init(); // init with some delay to init zmq connection
    });
    after(async function () {
        await clearRepoData();
        zmqObserver.destroy();
        zmqPublisher.destroy();
    });

    it('should extend position from the JSON/BIN converter with trackable details', function (done) {
        const association = DbSeeds.associations[0];
        const data = createData(association.mac);

        const subscription = zmqObserver.subscribe(ZMQ_PUB_CHANNELS.DATA, function (zmqMsg, channel) {
            assert(ZMQ_PUB_CHANNELS.DATA === channel, `Message channel not equal to ${ZMQ_PUB_CHANNELS.DATA}`);
            assert(zmqMsg.tk_uid === association.trackable_uid, `Trackable uid is not identified`);
            assert(zmqMsg.ts === data.ts, `Position timestamp not equal to ${data.ts}`);
            assert(zmqMsg.hex === data.hex, `hex not equal to ${data.hex}`);
            done();
        });
        subscription.then(() => {
            zmqPublisher.sendToMp(ZMQ_SUB_CHANNELS.DATA, data);
        });
    });

    it('should not extend position with trackable details on not associated trackable', function (done) {
        const association = {};
        const data = createData(association.mac);

        const subscription = zmqObserver.subscribe(ZMQ_PUB_CHANNELS.DATA, function (zmqMsg, channel) {
            assert(ZMQ_PUB_CHANNELS.DATA === channel, `Message channel not equal to ${ZMQ_PUB_CHANNELS.DATA}`);
            assert(zmqMsg.tk_uid === null, `Trackable uid should not be identified`);
            assert(zmqMsg.ts === data.ts, `Position timestamp not equal to ${data.ts}`);
            assert(zmqMsg.hex === data.hex, `hex not equal to ${data.hex}`);
            done();
        });
        subscription.then(() => {
            zmqPublisher.sendToMp(ZMQ_SUB_CHANNELS.DATA, data);
        });
    });
});
