import { createRequire } from 'module';
import assert from 'assert';

import { ZMQ_PUB_CHANNELS, ZMQ_SUB_CHANNELS } from '../../lib/system/constants.mjs';
import { ZmqObserver, ZmqPublisher } from '../utils/index.mjs';
import { Server, createData, initRepoData, clearRepoData } from './helpers.mjs';
const require = createRequire(import.meta.url);
const DbSeeds = require('../seeds/data.json');

describe('Handle ~obsolete message and re translate to $obsolete', function () {
    // ~obsolete and obsolete descriptions: https://redpointpositioning.atlassian.net/wiki/spaces/REDPOINT/pages/1314031083/Platform+Message+Processor#Handling-%E2%80%9Cobsolete%E2%80%9D-messages
    const zmqObserver = new ZmqObserver();
    const zmqPublisher = new ZmqPublisher();

    before(async function () {
        await Server().init();
        await initRepoData();
        zmqObserver.init();
        await zmqPublisher.init(); // init with some delay to init zmq connection
    });
    after(async function () {
        await clearRepoData();
        zmqObserver.destroy();
        zmqPublisher.destroy();
    });

    it('should extend position from the JSON/BIN converter with trackable details', function (done) {
        const association = DbSeeds.associations[0];
        const data = createData(association.mac);

        const subscription = zmqObserver.subscribe(ZMQ_PUB_CHANNELS.OBSOLETE, function (zmqMsg, channel) {
            assert(ZMQ_PUB_CHANNELS.OBSOLETE === channel, `Message channel not equal to ${ZMQ_PUB_CHANNELS.OBSOLETE}`);
            assert(zmqMsg.ts === data.ts, `Obsolete timestamp not equal to ${data.ts}`);
            assert(zmqMsg.hex === data.hex, `Obsolete hex not equal to ${data.hex}`);
            done();
        });
        subscription.then(() => {
            zmqPublisher.sendToMp(ZMQ_SUB_CHANNELS.OBSOLETE, data);
        });
    });
});
