import ModelBase from '../ModelBase.mjs';
import { formatSublocation } from './formatters.mjs';

export class Sublocation extends ModelBase {
    /**
     * @method
     * @param {Object} params - options for read sublocation in repository
     * @property {String|undefined} params.sl_id - sublocation numeric identifier
     * @return {Promise<Object>}
     */
    async findById(params) {
        const { sl_id } = params;
        const sublocation = await this.repository.sublocation.findById(sl_id);
        return formatSublocation(sublocation);
    }

    /**
     * @method
     * @param {Object} params - options for read sublocation in repository
     * @property {String} params.sl_id - sublocation numeric identifier
     * @property {Number} params.x  - the X coordinate of the position
     * @property {Number} params.y  - the Y coordinate of the position
     * @property {Number} params.z  - the Z coordinate of the position
     * @property {Number} params.sl_id  - sublocation numeric identifier
     * @property {Number} params.fom  - the figure of merit
     * @return {Promise<String>}
     */
    // todo: function has ById so should have Id as arguments not an object
    async findUidById(params) {
        const { sl_id } = params;
        return await this.repository.sublocation.findUidById(sl_id);
    }
}
