import UseCaseBase from '../UseCaseBase.mjs';
import { Data, Device, NodeAssociation } from '../../models/index.mjs';

export class DataProxying extends UseCaseBase {
    /**
     *
     * @param {Object} params - data
     * @property {String} params.mac - hardware MAC address
     * @property {String} params.ts - data timestamp in ISO 8601 format
     * @property {String} params.hex - HEX data related to trackable
     * @example {
     *      mac: 'AC11828B1749'
     *      ts: '2021-07-01T12:44:11.720Z'
     *      hex: '0123456789ABCDF'
     * }
     * @return {Promise<null>}
     */
    async execute(params) {
        const association = await new NodeAssociation().findByMac(params);
        const data = {
            mac: params.mac,
            ts: params.ts,
            hex: params.hex,
            tk_uid: association ? association.trackable_uid : null,
        };
        await this.notificator.notify(Data.notifyMessage(data));
        await new Device().updateLastHeard(params.mac, params.ts);

        return null;
    }
}
