/**
 * @function
 * @param {Object} rawPos - input position from ZMQ
 * @param {String} trackableUid - trackable unique identifier
 * @param {String} sublocationUid - sublocation unique identifier
 * @param {String} type - position type
 * @return {Object} - extended position
 */
export function formatPosition(rawPos, trackableUid, sublocationUid, type) {
    const slvrMode = (rawPos?.data?.slvr_mode || '').toUpperCase();
    const er = slvrMode === '0D' ? rawPos.data.fom * 128 : null; // for 1D firmware always send fom equal to 50
    const res = {
        tk_uid: trackableUid,
        ts: rawPos.ts,
        data: {
            x: rawPos.data.x,
            y: rawPos.data.y,
            z: rawPos.data.z,
            sl_uid: sublocationUid,
            type,
            mac: rawPos.mac.toUpperCase(),
            er,
            slvr_mode: slvrMode,
            fom: rawPos.data.fom,
            inactive: rawPos.data.inactive,

        },
    };

    if ("src" in rawPos.data) {
        res.data.src = rawPos.data.src
    }
    if ("spd" in rawPos.data) {
        res.data.spd = rawPos.data.spd
    }
    if ("ornt" in rawPos.data) {
        res.data.ornt = rawPos.data.ornt
    }
    if ("spd_fom" in rawPos.data) {
        res.data.spd_fom = rawPos.data.spd_fom
    }
    if ("ornt_fom" in rawPos.data) {
        res.data.ornt_fom = rawPos.data.ornt_fom
    }
    if ("metrics" in rawPos.data) {
        res.data.metrics = rawPos.data.metrics
    }

    return res;
}
