import express from 'express';
import controllers from './controllers/index.mjs';

const router = express.Router();

router.get('/trackables/:uid', controllers.trackables.get);
router.get('/trackables', controllers.trackables.getAll);
router.put('/trackables/:uid', controllers.trackables.put);
router.post('/trackables', controllers.trackables.post);
router.delete('/trackables/:uid', controllers.trackables.del);

router.get('/anchors', controllers.anchors.getAll);
router.get('/anchors/:uid', controllers.anchors.get);
router.put('/anchors/:uid', controllers.anchors.put);
router.post('/anchors', controllers.anchors.post);
router.delete('/anchors/:uid', controllers.anchors.del);

router.get('/locations', controllers.locations.getAll);
router.get('/locations/:uid', controllers.locations.get);
router.put('/locations/:uid', controllers.locations.put);
router.post('/locations', controllers.locations.post);
router.delete('/locations/:uid', controllers.locations.del);

router.get('/sublocations', controllers.sublocations.getAll);
router.get('/sublocations/:uid', controllers.sublocations.get);
router.put('/sublocations/:uid', controllers.sublocations.put);
router.post('/sublocations', controllers.sublocations.post);
router.delete('/sublocations/:uid', controllers.sublocations.del);

router.get('/nodes', controllers.nodes.getAll);
router.get('/nodes/:mac', controllers.nodes.get);
router.post('/nodes', controllers.nodes.post);
router.delete('/nodes/:mac', controllers.nodes.del);

router.get('/node_assignments', controllers.nodeAssociations.getAll);
router.post('/node_assignments', controllers.nodeAssociations.post);
router.put('/node_assignments', controllers.nodeAssociations.put);

router.get('/tag_assignments', controllers.tagAssociations.getAll);
router.post('/tag_assignments', controllers.tagAssociations.post);
router.put('/tag_assignments', controllers.tagAssociations.put);

router.get('/tags', controllers.tags.getAll);
router.get('/tags/:mac', controllers.tags.get);
router.post('/tags', controllers.tags.post);
router.delete('/tags/:mac', controllers.tags.del);

router.get('/hardware_devices', controllers.devices.getAll);
router.get('/hardware_devices/:mac', controllers.devices.get);
router.post('/hardware_devices', controllers.devices.post);

router.get('/network/settings', controllers.networkSettings.getAll);
router.get('/network/settings/:location_uid', controllers.networkSettings.get);
router.post('/network/settings', controllers.networkSettings.post);
router.delete('/network/settings/:location_uid', controllers.networkSettings.del);

router.get('/network/lsb_schedules', controllers.networkLsbSchedule.getAll);
router.get('/network/lsb_schedules/:uid', controllers.networkLsbSchedule.get);
router.post('/network/lsb_schedules', controllers.networkLsbSchedule.post);
router.put('/network/lsb_schedules/:uid', controllers.networkLsbSchedule.put);
router.delete('/network/lsb_schedules/:uid', controllers.networkLsbSchedule.del);

router.post('/log', controllers.log.post);

export default router;
