import { NODE_TYPE } from '../../system/constants.mjs';
import { NodeBase } from './NodeBase.mjs';

/**
 * @swagger
 * components:
 *  schemas:
 *      TagCreateBody:
 *          type: object
 *          properties:
 *              mac:
 *                  type: string
 *                  description: hardware MAC address 12 characters length (6 bytes heximal value).
 *      Tag:
 *          type: object
 *          properties:
 *              mac:
 *                  type: string (6 bytes)
 *                  description: The MAC address of the tag hardware, in upper case.
 *              node_id:
 *                  type: number
 *                  description: Numeric unique (within the server) identifier of the tag. Value in the frame of 1…65535.
 *              last_heard:
 *                  type: string (ISO 8601)
 *                  description: The time stamp of the last time the tag reported to the server, in ISO 8601 format.
 *              created_at:
 *                  type: string (ISO 8601)
 *                  description: The time stamp when the tag was created, in ISO 8601 format.
 *              cbid:
 *                  type: string
 *                  description: The carrier board identifier.
 *      Tags:
 *          type: object
 *          properties:
 *              tags:
 *                  type: array
 *                  items:
 *                      $ref: '#/components/schemas/Tag'
 */
export class Tag extends NodeBase {
    /**
     * @property {String|null}
     */
    static object = 'tag';

    constructor() {
        super(NODE_TYPE.TO);
    }
}
