import ModelBase from '../ModelBase.mjs';
import { toISOTime } from '../../utils/index.mjs';
import { SublocationId } from '../id/index.mjs';

export class Sublocation extends ModelBase {
    /**
     *
     * @param sublocation {SolutionSublocation}
     * @returns {PlatformSublocation}
     */
    static formatSolutionSublocation(sublocation) {
        const elevation = isNaN(sublocation.offset_z) ? 0 : Math.floor(sublocation.offset_z / 10) * 10;
        return {
            uid: sublocation.uid,
            name: sublocation.name,
            created_at: toISOTime(sublocation.created_at),
            updated_at: toISOTime(sublocation.updated_at),
            location_uid: sublocation.loc_uid,
            elevation,
        }
    }

    /**
     *
     * @param sublocation {PlatformSublocation}
     * @returns {PlatformSublocation}
     */
    static formatPlatformSublocation(sublocation) {
        return {
            uid: sublocation.uid,
            name: sublocation.name,
            created_at: sublocation.created_at,
            updated_at: sublocation.updated_at,
            location_uid: sublocation.location_uid,
            elevation: Number(sublocation.elevation),
        }
    }
    
    /**
     *
     * @returns {Promise<SolutionSublocation[]>}
     */
    async collectSolutionEntities() {
        return (await this.solutionRepositoryInstance.sublocation.readAll()).map(Sublocation.formatSolutionSublocation)
    }
    
    /**
     *
     * @returns {Promise<PlatformSublocation[]>}
     */
    async collectPlatformEntities() {
        return (await this.platformRepositoryInstance.sublocation.findAll()).map(Sublocation.formatPlatformSublocation)
    }
    
    /**
     *
     * @param items {PlatformSublocation[]}
     * @returns {Promise<void>}
     */
    async addToPlatform(items) {
        for (const item of items) {
            item.id = Number(await this.platformRepositoryInstance.sublocationId.nextValue());
            await this.platformRepositoryInstance.sublocation.save(item);
            await this.solutionRepositoryInstance.sublocation.update(item.id, item.uid);
        }
    }
    
    /**
     *
     * @param items {PlatformSublocation[]}
     * @returns {Promise<void>}
     */
    async removeInPlatform(items) {
        for (const item of items) {
            const { uid } = item;
            const sublocation = await this.platformRepositoryInstance.sublocation.findByUid(uid);
            if (!sublocation) {
                return ;
            }
            await this.platformRepositoryInstance.sublocation.deleteByUid(uid);
            await new SublocationId().remove(sublocation.id);
        }
    }
    
    /**
     *
     * @param items {PlatformSublocation[]}
     * @returns {Promise<void>}
     */
    async updateInPlatform(items) {
        for (const item of items) {
            const sublocation = await this.platformRepositoryInstance.sublocation.findByUid(item.uid);
            if (sublocation) {
                await this.platformRepositoryInstance.sublocation.save({ ...item, id: sublocation.id });
            }
        }
    }
}
