import RepoBase from '../RepoBase.mjs';

/**
 * @typedef SolutionNode {Object}
 * @property uid {String}
 * @property mac_address {String}
 * @property last_heard {Date}
 * @property created_at {Date}
 * @property updated_at {Date}
 * @property node_type {String}
 * @property parameters {Object}
 */

/**
 * @class NodeRepository
 * @description create access for the nodes in the solutions DB
 */
export class NodeRepository extends RepoBase {
    /**
     * @param {Object} options - repository options
     * @param {Object} options.repositoryInstance - database connection
     */
    constructor(options) {
        const { repositoryInstance } = options;
        super(repositoryInstance);
    }

    /**
     * @method
     * @return {Promise<SolutionNode[]>} returns result of search by key
     */
    async readAll() {
        return (await this.repoInstance.queryAsync(NodeRepository.readAllSql) || []);
    }
    
    static get readAllSql() {
        return `select
                    uid, mac_address, last_heard, created_at, updated_at, node_type, parameters
                from view_nodes;`;
    }
}
