import { createRequire } from 'module';
import sinon from 'sinon';
import assert from 'assert';
import { SolutionDBPoolFactory } from '../lib/db/solutionDBClient.js';
import { fakeQueryAsync, Service } from './helpers.mjs';
const require = createRequire(import.meta.url);
const dbData = require('./solution-db-data.json');

describe('Trackables transfer', function() {
    let solutionPoolStub;
    let platformRepository;
    let resultTKOs;
    
    before(async function() {
        solutionPoolStub = sinon.stub(SolutionDBPoolFactory, 'createSolutionDBPool');
        solutionPoolStub.callsFake(() => ({ queryAsync: fakeQueryAsync }));
        const result = await Service().init();
        platformRepository = result.platformRepository;
    });
    
    after(async function() {
        SolutionDBPoolFactory.createSolutionDBPool.restore();
        
        if (Array.isArray(resultTKOs)) {
            for (const trackable of resultTKOs) {
                await platformRepository.trackable.del({ uid: trackable.uid });
            }
        }
    });
    
    it('Move Trackables', async function() {
        resultTKOs = await platformRepository.trackable.findAll();

        resultTKOs.forEach((tko) => {
            const expectedTko = dbData.trackables.expect.find((solutionTko) => {
                return solutionTko.uid === tko.uid;
            });
            assert.deepStrictEqual(tko, expectedTko);
        });
    });
});
